@@ -1,4 +1,8 @@
-# SPDX-License-Identifier: Apache-2.0.
+# Copyright 2018-2022 contributors to the OpenLineage project
+# SPDX-License-Identifier: Apache-2.0
+
+from typing import List
+from openlineage.common.sql import DbTableMeta
 
 
 class DbColumn:
@@ -25,7 +29,7 @@ class DbTableSchema:
         self,
         schema_name: str,
         table_name: "DbTableMeta",  # noqa: F821
-        columns: [DbColumn]
+        columns: List[DbColumn]
     ):
         self.schema_name = schema_name
         self.table_name = table_name
